/****************************************************************
*  Name    : RiconoscimentoVocale								*
*  Author  : Davide Ferrario                                    *
*  Notice  : Copyright 2011 All Rights Reserved                 *
*  Date    : 25/05/2011                                         *
*  Notes   : Activity gestione Riconoscimento comandi vocali   	*
*          :													*
****************************************************************/

// Definizione Package
package BlackProject.HouseSpeechDemo;

// Inclusione librerie
import java.util.ArrayList;
import java.util.List;
import android.app.Activity;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.content.pm.ResolveInfo;
import android.speech.RecognizerIntent;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.os.Bundle;
import android.os.Handler;

// Classe Control del progetto HouseSpeechDemo
public class RiconoscimentoVocale extends Activity implements OnClickListener {
	private static final int VOICE_RECOGNITION_REQUEST_CODE = 1234;

	// Creo nuova classe gestione protocollo ethernet
	private EthernetProtocol ethernetProtocol = new EthernetProtocol();
	
	// Oggetti grafici finestra
	private Button ButtonSpeak = null;
	
	private Handler handler = new Handler();
	private Context context = this;

	/** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
    	super.onCreate(savedInstanceState);
    	setContentView(R.layout.riconoscimentovocale);
    	
        // Inizializza configurazione completa programma
    	Utility.LeggiConfigurazioneCompleta (context);
    	
    	// Rilevo oggetti grafici
    	ButtonSpeak = (Button) findViewById(R.id.ButtonSpeak);

    	// Verifico se rilevata recognition activity
        PackageManager packageManager = getPackageManager();
        List<ResolveInfo> activities = packageManager.queryIntentActivities(new Intent(RecognizerIntent.ACTION_RECOGNIZE_SPEECH), 0);
        // Se non rilevata recognition activity
        if (activities.size() == 0) {
        	ButtonSpeak.setEnabled(false);
			// Segnalo errore
			Utility.ShowSimpleDialog ("Warning",
									  "Recognition activity not available.",
									  R.drawable.iconaerrorealert, context, handler,
									  new DialogInterface.OnClickListener() {
									  		public void onClick (DialogInterface dialog, int arg1) {
									  			// Termino activity
												finish();
											}
									  }); 
        }		// Chiusura if non rilevata recognition activity
       	// Se rilevata recognition activity
        else {
        	ButtonSpeak.setOnClickListener(this);
        	ButtonSpeak.setEnabled(true);
        }		// Chiusura else rilevata recognition activity
    }		// Chiusura funzione onCreate

    // Eseguita quando l'activity viene visualizzata
    @Override
    public void onResume() {
    	super.onResume();
    	
        // Inizializza configurazione completa programma
    	Utility.LeggiConfigurazioneCompleta (context);
    	
    	// Visualizzo activity
    	setVisible(true);
    }		// Chiusura funzione onResume

    // Eseguita quando l'activity viene nascosta
	@Override
	public void onPause() {
    	// Nascondo activity
    	setVisible(false);

    	super.onPause();
	}		// Chiusura funzione onPause

    // Eseguita quando l'activity viene terminata
    @Override
    public void onDestroy() {
    	// Nascondo activity
    	setVisible(false);

    	super.onDestroy();
    }		// Chiusura funzione onDestroy
    
	// Funzione richiamata quando viene premuto un pulsante
	public void onClick(View target) {
		// Seleziono ID pulsante premuto
		switch (target.getId()) {
			// Se premuto pulsante Speak
			case R.id.ButtonSpeak:
	        	// Avvio activity speech recognition
	        	startSpeechRecognition();
	        	// Nascondo activity
	        	setVisible(false);
				break;		// Chiusura case premuto pulsante Speak
		}		// Chiusura switch seleziono ID pulsante premuto
	}		// Chiusura funzione onClick

    // Avvia activity speech recognition
    private void startSpeechRecognition() {
    	Intent intent = new Intent(RecognizerIntent.ACTION_RECOGNIZE_SPEECH);
    	intent.putExtra(RecognizerIntent.EXTRA_LANGUAGE_MODEL, RecognizerIntent.LANGUAGE_MODEL_FREE_FORM);
    	intent.putExtra(RecognizerIntent.EXTRA_PROMPT, "Speech recognition demo");
    	startActivityForResult(intent, VOICE_RECOGNITION_REQUEST_CODE);    	
    }		// Chiusura funzione startSpeechRecognition

    @Override    
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
    	// Se risultato proveniente da Voice Recognition
    	if (requestCode == VOICE_RECOGNITION_REQUEST_CODE) {
    		// Seleziono codice risultato
    		switch (resultCode) {
    			// Se eseguito riconoscimento vocale
    			case RESULT_OK:
            		// Fill the list view with the strings the recognizer thought it could have heard 
            		ArrayList<String> matches = data.getStringArrayListExtra(RecognizerIntent.EXTRA_RESULTS);

            		// Considero tutti i comandi ricevuti
            		for (String match : matches)
            			// Verifico esecuzione comando dalla stringa
            			VerificaEsecuzioneComando (match);
    				break;		// Chiusura case eseguito riconoscimento vocale
    				
       			// Se riconoscimento non riuscito
    			case RecognizerIntent.RESULT_NO_MATCH:
    				break;		// Chiusura case riconoscimento non riuscito    				

    			// Se annullato riconoscimento vocale
    			case RESULT_CANCELED:
    				break;		// Chiusura case annullato riconoscimento vocale

    			// Se rilevato errore audio
    			case RecognizerIntent.RESULT_AUDIO_ERROR:
    				break;		// Chiusura case rilevato errore audio

    			// Se rilevato errore client
    			case RecognizerIntent.RESULT_CLIENT_ERROR:
    				break;		// Chiusura case rilevato errore client

    			// Se rilevato errore rete
    			case RecognizerIntent.RESULT_NETWORK_ERROR:
    				break;		// Chiusura case rilevato errore rete

    			// Se rilevato errore server
    			case RecognizerIntent.RESULT_SERVER_ERROR:
    				break;		// Chiusura case rilevato errore server    				
    		}		// Chiusura switch seleziono codice risultato

    		// Visualizzo activity
        	setVisible(true);
    	}		// Chiusura if risultato proveniente da Voice Recognition

    	super.onActivityResult(requestCode, resultCode, data);
    }		// Chiusura funzione onActivityResult
    
	// Verifico esecuzione comando dalla stringa
    // INPUT:	Stringa del comando completo
    // OUTPUT:	Flag riuscita riconoscimento/esecuzione comando
    //				false -> riconoscimento/esecuzione FAULT
    //				true -> riconoscimento/esecuzione OK
	private boolean VerificaEsecuzioneComando (String match) {
		// Stringhe singole parole del comando
    	String singoleParole[] = match.split(" ");
		// Ottengo stringhe dei comandi
		String StringheComandi[] = Utility.getStringheComandi();
		// Numero del rele selezionato
    	int releNum = 0;
    	// Flag trovato un rele selezionato
    	boolean foundNumber = false;

		// Provo ad estrarre il numero rele
		for (int i = 0; i < singoleParole.length; i++) {
			try {
				releNum = Integer.parseInt(singoleParole[i]);
				foundNumber = true;
				// Blocco ciclo for provo ad estrarre il numero rele
				break;
			} catch (Exception e) {}
		}		// Chiusura ciclo for provo ad estrarre il numero rele

		// Se selezionato rele valido
		if ((foundNumber == true) && (releNum >= 1) && (releNum <= 8)) {
			// Verifico stringhe dei comandi
			for (int indiceComando = 0; indiceComando < 3; indiceComando++) {
				// Verifico stringhe singole parole
   				for (int indiceParola = 0; indiceParola < singoleParole.length; indiceParola++) {
   					// Se trovata stringa corrispondente a un comando
   					if (StringheComandi[indiceComando].equalsIgnoreCase(singoleParole[indiceParola]) == true) {
   						// Seleziono indice comando
   						switch (indiceComando) {
   							// Se comando attivazione
   							case 0:
   								// Eseguo comando attivazione
   								ethernetProtocol.AttivazioneRele ((byte) (releNum - 1));
   								break;		// Chiusura case comando attivazione

   							// Se comando disattivazione
   							case 1:
   								// Eseguo comando disattivazione
   								ethernetProtocol.DisattivazioneRele ((byte) (releNum - 1));
   								break;		// Chiusura case comando disattivazione
   								
  	   						// Se comando inversione
   							case 2:
   								// Eseguo comando inversione
   								ethernetProtocol.InversioneRele ((byte) (releNum - 1));
   								break;		// Chiusura case comando inversione
   						}		// Chiusura switch seleziono indice comando
   						
   						// Riconoscimento/esecuzione OK
   						return (true);
   					}		// Chiusura if trovata stringa corrispondente a un comando
   				}		// Chiusura ciclo for verifico stringhe singole parole
			}		// Chiusura ciclo for verifico stringhe dei comandi

			// Riconoscimento/esecuzione FAULT
			return (false);
		}		// Chiusura if selezionato rele valido
		else
			// Riconoscimento/esecuzione FAULT
			return (false);
	}		// Chiusura funzione VerificaEsecuzioneComando
}		// Chiusura classe RiconoscimentoVocale