/****************************************************************
*  Name    : Setting											*
*  Author  : Davide Ferrario                                    *
*  Notice  : Copyright 2011 All Rights Reserved                 *
*  Date    : 14/05/2011                                         *
*  Notes   : Classe gestione impostazioni del progetto	    	*
*          :													*
****************************************************************/

// Definizione Package
package BlackProject.HouseSpeechDemo;

//Inclusione librerie
import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.EditText;
import android.widget.Button;
import java.util.regex.Pattern;
import java.util.regex.Matcher;

// Classe Settings del progetto HouseSpeechDemo
public class Settings extends Activity implements OnClickListener {
	// Oggetti grafici
	private EditText EditTextIPDestinatario = null;
	private EditText EditTextPortaTCP = null;
	private EditText EditTextComandoON = null;
	private EditText EditTextComandoOFF = null;
	private EditText EditTextComandoTOGGLE = null;

	private Button PulsanteOk = null;

	private Handler handler = new Handler();

	private Context context = this;

	// Eseguita quando l'activity viene creata per la prima volta
    @Override
    public void onCreate (Bundle savedInstanceState) {
		super.onCreate (savedInstanceState);
    	setContentView (R.layout.settings);

    	// Rilevo oggetti grafici
    	EditTextIPDestinatario = (EditText) findViewById (R.id.EditTextIPDestinatario);
    	EditTextPortaTCP = (EditText) findViewById (R.id.EditTextPortaTCP);
    	EditTextComandoON = (EditText) findViewById (R.id.EditTextComandoON);
    	EditTextComandoOFF = (EditText) findViewById (R.id.EditTextComandoOFF);
    	EditTextComandoTOGGLE = (EditText) findViewById (R.id.EditTextComandoTOGGLE);

    	// Rilevo oggetto pulsante ok
    	PulsanteOk = (Button) findViewById (R.id.PulsanteOk);
    	PulsanteOk.setEnabled (true);
    	PulsanteOk.setOnClickListener (this);
    }		// Chiusura funzione onCreate

    // Eseguita quando l'activity viene visualizzata
    @Override
    public void onResume() {
    	super.onResume();

    	// Imposto IP destinatario campo edittext
    	EditTextIPDestinatario.setText (Utility.getIPAddressDestinatario());
    	// Imposto porta TCP campo edittext
    	EditTextPortaTCP.setText (Utility.getPortaTCP());
    	// Imposto campi comandi vocali
    	EditTextComandoON.setText (Utility.getStringheComandi()[0]);
    	EditTextComandoOFF.setText (Utility.getStringheComandi()[1]);
    	EditTextComandoTOGGLE.setText (Utility.getStringheComandi()[2]);
    }		// Chiusura funzione onResume

    // Eseguita quando l'activity viene nascosta
	@Override
	public void onPause() {
		
		
		
		super.onPause();
	}		// Chiusura funzione onPause

    // Eseguita quando l'activity viene terminata
    @Override
    public void onDestroy() {

    	
    	
    	super.onDestroy();
    }		// Chiusura funzione onDestroy

    // Funzione richiamata quando viene premuto un pulsante
    public void onClick (View target) {
    	// Seleziono ID pulsante premuto
    	switch (target.getId()) {
			// Se premuto pulsante invia
			case R.id.PulsanteOk:
				// Avvio memorizzazione indirizzo IP/Porta TCP
				MemorizzaIPPortaTCP();
				break;		// Chiusura case premuto pulsante invia
    	}		// Chiusura switch seleziono ID pulsante premuto
    }		// Chiusura funzione onClick

    // Gestione verifica/memorizzazione indirizzo IP/porta TCP
	private void MemorizzaIPPortaTCP() {
		// Se IP destinazione digitato errato
		if (Verifica_IPDestinazione() == false) {
			// Segnalo errore
			Utility.ShowSimpleDialog ("Warning",
									  "Error on IP address.",
									  R.drawable.iconaerrorealert, context, handler, null);
			// Mi posizione su campo IP
			EditTextIPDestinatario.requestFocus();

			// Termino funzione
			return;
		}		// Chiusura if IP destinazione digitato errato

		// Imposto IP destinazione digitato
		Utility.setIPAddressDestinatario (EditTextIPDestinatario.getText().toString());
		// Imposto porta TCP digitata
		Utility.setPortaTCP (EditTextPortaTCP.getText().toString());
		// Imposto comandi vocali
		String StringheComandiTMP[] = new String[] {EditTextComandoON.getText().toString(),
												  	EditTextComandoOFF.getText().toString(),
												  	EditTextComandoTOGGLE.getText().toString()};
		Utility.setStringheComandi(StringheComandiTMP);
		// Memorizzo configurazione completa programma
		Utility.MemorizzaConfigurazioneCompleta (context);

		// Segnalo conferma
		Utility.ShowSimpleDialog ("OK",
								  "Settings correctly stored.",
								  R.drawable.iconaconfermaalert, context, handler, null);
	}		// Chiusura funzione MemorizzaIPPortaTCP

    // Verifica IP destinazione digitato errato
	// 		false -> IP destinazione digitato errato
	// 		true -> IP destinazione digitato corretto
	private boolean Verifica_IPDestinazione() {
		Pattern pattern = null;
		Matcher matcher;
		final String IPADDRESS_PATTERN = "^([01]?\\d\\d?|2[0-4]\\d|25[0-5])\\.([01]?\\d\\d?|2[0-4]\\d|25[0-5])\\.([01]?\\d\\d?|2[0-4]\\d|25[0-5])\\.([01]?\\d\\d?|2[0-4]\\d|25[0-5])$";

		// Creo pattern di verifica
		if (pattern == null)
			pattern = Pattern.compile (IPADDRESS_PATTERN);

		// Verifico indirizzo IP con pattern
		matcher = pattern.matcher (EditTextIPDestinatario.getText().toString());
		// Ritorno risultato verifica
		return (matcher.matches());
	}		// Chiusura funzione Verifica_IPDestinazione
}		// Chiusura classe Settings