/****************************************************************
*  Name    : Utility											*
*  Author  : Davide Ferrario                                    *
*  Notice  : Copyright 2011 All Rights Reserved                 *
*  Date    : 13/05/2011                                         *
*  Notes   : Classe gestione utility					    	*
*          :													*
****************************************************************/

//Definizione package
package BlackProject.HouseSpeechDemo;

// Inclusione library
import android.app.Activity;
import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.DialogInterface.OnClickListener;
import android.content.SharedPreferences;
import android.os.Handler;

// Definizione classe Utility
public class Utility {
	// Gestisce la segnalazione di un messaggio tramite Dialog
    public static void ShowSimpleDialog (String Title, String Message, int Icona,
    									 Context context, Handler handler,
    									 OnClickListener clickListener) {
        class ShowSimpleDialogClasse implements Runnable {
        	private String Title;
        	private String Message;
        	private int Icona;
        	private Context context;
        	private OnClickListener clickListener;

        	// Costruttore classe ShowSimpleDialogClasse
        	private ShowSimpleDialogClasse (String Title, String Message, int Icona,
        									Context context, Handler handler,
        									OnClickListener clickListener) {
        		
        		this.Title = Title;
            	this.Message = Message;
            	this.Icona = Icona;
            	this.context = context;
            	this.clickListener = clickListener;
            	handler.post (this);
        	}		// Chiusura costruttore classe ShowSimpleDialogClasse

        	public void run() {
        		AlertDialog.Builder alertDialog = null;

        		// Visualizzo SimpleDialog
        		alertDialog = new AlertDialog.Builder (context);
        		alertDialog.setTitle (Title);
        		alertDialog.setMessage (Message);
        		alertDialog.setIcon (Icona);
        		alertDialog.setNeutralButton("Close", clickListener);
        		alertDialog.show();
        	}
        }		// Chiusura classe ShowSimpleDialogClasse

        try {
        	new ShowSimpleDialogClasse (Title, Message, Icona, context, handler, clickListener);
        } catch (Exception e) {}
    }		// Chiusura funzione ShowSimpleDialog

    // Gestisce la richiesta di conferma tramite un messaggio Dialog
    public static void ShowConfirmationDialog (String Title, String Message, int Icona,
    										   Context context, Handler handler,
    										   OnClickListener positiveClickListener,
    										   OnClickListener negativeClickListener) {
        class ShowConfirmationDialogClasse implements Runnable {
        	private String Title;
        	private String Message;
        	private int Icona;
        	private Context context;
        	private OnClickListener positiveClickListener;
        	private OnClickListener negativeClickListener;

        	// Costruttore classe ShowConfirmationDialogClasse
        	private ShowConfirmationDialogClasse (String Title, String Message, int Icona,
        										  Context context, Handler handler,
        										  OnClickListener positiveClickListener,
        										  OnClickListener negativeClickListener) {
            	this.Title = Title;
            	this.Message = Message;
            	this.Icona = Icona;
            	this.context = context;
            	this.positiveClickListener = positiveClickListener;
            	this.negativeClickListener = negativeClickListener;
            	handler.post (this);
        	}		// Chiusura costruttore classe ShowConfirmationDialogClasse

        	public void run() {
        		AlertDialog.Builder alertDialog = null;

        		// Visualizzo ConfirmationDialog
        		alertDialog = new AlertDialog.Builder (context);
        		alertDialog.setTitle (Title);
        		alertDialog.setMessage (Message);
        		alertDialog.setIcon (Icona);
        		alertDialog.setPositiveButton("Ok", positiveClickListener);
        		alertDialog.setNegativeButton("Cancel", negativeClickListener);
        		alertDialog.setCancelable (false);
        		alertDialog.show();
        	}
        }		// Chiusura classe ShowConfirmationDialogClasse

        try {
        	new ShowConfirmationDialogClasse (Title, Message, Icona, context, handler, positiveClickListener, negativeClickListener);
        } catch (Exception e) {}
    }		// Chiusura funzione ShowConfirmationDialog

	private static ProgressDialog progressDialog = null;

	// Gestisce la visualizzazione di un ProgressDialog
    public static void ShowProgressDialog (String Title, String Message, Context context, Handler handler) {
        class ShowProgressDialogClasse implements Runnable {
        	private String Title;
        	private String Message;
        	private Context context;

        	// Costruttore classe ShowProgressDialogClasse
        	private ShowProgressDialogClasse (String Title, String Message, Context context, Handler handler) {
            	this.Title = Title;
            	this.Message = Message;
            	this.context = context;
            	handler.post (this);
        	}		// Chiusura costruttore classe ShowProgressDialogClasse

        	public void run() {
        		// Visualizzo ProgressDialog
    			progressDialog = ProgressDialog.show(context, Title, Message, false);
        	}
        }		// Chiusura classe ShowProgressDialogClasse

        try {
        	// Nascondo ProgressDialog
        	if (progressDialog != null)
        		progressDialog.dismiss();
        	progressDialog = null;
        	new ShowProgressDialogClasse (Title, Message, context, handler);
        } catch (Exception e) {}
    }		// Chiusura funzione ShowProgressDialog

    // Nasconde un ProgressDialog
    public static void HideProgressDialog () {
		// Nascondo ProgressDialog
    	if (progressDialog != null)
    		progressDialog.dismiss();
    	progressDialog = null;
    }		// Chiusura funzione HideProgressDialog
    
/* *********************************************************** */
/*        Definizione funzioni gestione configurazione         */
/* *********************************************************** */
    // Inizializza la configurazione completa del programma
    public static void LeggiConfigurazioneCompleta (Context context) {
	    // Inizializzo indirizzo IP della scheda destinazione
	    LeggiIPDestinatario (context);
	    // Inizializzo porta TCP comunicazione
	    LeggiPortaTCP (context);
        // Inizializzo stringhe dei comandi
        LeggiStringheComandi (context);
    }		// Chiusura funzione LeggiConfigurazioneCompleta
    
    // Memorizza nel RecordStore la configurazione completa del programma
    public static void MemorizzaConfigurazioneCompleta (Context context) {
	    // Memorizzo indirizzo IP della scheda destinazione
	    MemorizzaIPDestinatario (context);
	    // Memorizzo porta TCP comunicazione
	    MemorizzaPortaTCP (context);
        // Memorizzo stringhe dei comandi
	    MemorizzaStringheComandi (context);
    }		// Chiusura funzione MemorizzaConfigurazioneCompleta
    
/* *********************************************************** */
/*     Definizione funzioni gestione IP scheda destinazione    */
/* *********************************************************** */
    // Indirizzo IP scheda destinazione
	private static String IPAddressDestinatario = null;
	private static final String IPAddressDestinatarioDefault = "192.168.1.201";

	// Ottiene l'indirizzo IP della scheda destinazione
    public static String getIPAddressDestinatario() {
        return (IPAddressDestinatario);
    }       // Chiusura funzione getIPAddressDestinatario

    // Imposta l'indirizzo IP della scheda destinazione
    public static void setIPAddressDestinatario (String IPAddressDestinatarioTMP) {
    	IPAddressDestinatario = IPAddressDestinatarioTMP;
    }       // Chiusura funzione setIPAddressDestinatario

    // Inizializza l'indirizzo IP della scheda destinazione
    private static void LeggiIPDestinatario (Context context) {
    	try {
    		// Ottengo oggetto lettura persistente
    		SharedPreferences IPDestinatarioSetting = context.getSharedPreferences ("HouseSpeech", Activity.MODE_PRIVATE);
    		// Leggo IP Destinatario salvato
    		IPAddressDestinatario = IPDestinatarioSetting.getString ("IPAddressDestinatario", IPAddressDestinatarioDefault);
    	} catch (Exception e) {
    		IPAddressDestinatario = IPAddressDestinatarioDefault;
    	}
    }       // Chiusura funzione LeggiIPDestinatario

    // Memorizza nel RecordStore l'indirizzo IP della scheda destinazione
    private static void MemorizzaIPDestinatario (Context context) {
    	try {
    		// Ottengo oggetto scrittura persistente
    		SharedPreferences IPDestinatarioSetting = context.getSharedPreferences ("HouseSpeech", Activity.MODE_PRIVATE);
    		// Ottengo oggetto editor
    		SharedPreferences.Editor editor = IPDestinatarioSetting.edit();
    		// Aggiungo IP Destinatario
    		editor.putString ("IPAddressDestinatario", IPAddressDestinatario);
    		// Scrivo IP Destinatario
    		editor.commit();
    	} catch (Exception e) {}
    }       // Chiusura funzione MemorizzaIPDestinatario

/* *********************************************************** */
/*    Definizione funzioni gestione porta TCP comunicazione    */
/* *********************************************************** */
    // Porta TCP comunicazione
	private static String PortaTCP = null;
	private static final String PortaTCPDefault = "80";

	// Ottiene la porta TCP comunicazione
    public static String getPortaTCP() {
        return (PortaTCP);
    }       // Chiusura funzione getPortaTCP

    // Imposta la porta TCP comunicazione
    public static void setPortaTCP (String PortaTCPTMP) {
    	PortaTCP = PortaTCPTMP;
    }       // Chiusura funzione setPortaTCP

    // Inizializza la porta TCP comunicazione
    private static void LeggiPortaTCP (Context context) {
    	try {
    		// Ottengo oggetto lettura persistente
    		SharedPreferences PortaTCPSetting = context.getSharedPreferences ("HouseSpeech", Activity.MODE_PRIVATE);
    		// Leggo porta TCP comunicazione salvata
    		PortaTCP = PortaTCPSetting.getString ("PortaTCP", PortaTCPDefault);
    	} catch (Exception e) {
    		PortaTCP = PortaTCPDefault;
    	}
    }       // Chiusura funzione LeggiPortaTCP

    // Memorizza nel RecordStore la porta TCP comunicazione
    private static void MemorizzaPortaTCP (Context context) {
    	try {
    		// Ottengo oggetto scrittura persistente
    		SharedPreferences PortaTCPSetting = context.getSharedPreferences ("HouseSpeech", Activity.MODE_PRIVATE);
    		// Ottengo oggetto editor
    		SharedPreferences.Editor editor = PortaTCPSetting.edit();
    		// Aggiungo porta TCP comunicazione
    		editor.putString ("PortaTCP", PortaTCP);
    		// Scrivo porta TCP comunicazione
    		editor.commit();
    	} catch (Exception e) {}
    }       // Chiusura funzione MemorizzaPortaTCP
    
/* *********************************************************** */
/*       Definizione funzioni gestione stringhe comandi        */
/* *********************************************************** */
    // Stringhe comandi
	private static String StringheComandi[] = null;
	private static String StringheComandiDefault[] = new String[] {"attiva",
																   "disattiva",
																   "inverti"};
	// Ottiene le stringhe dei comandi
    public static String[] getStringheComandi() {
    	String StringheComandiTMP[] = new String[3];
    	
    	for (int i = 0; i < 3; i++)
    		StringheComandiTMP[i] = StringheComandi[i];
        
    	return (StringheComandiTMP);
    }       // Chiusura funzione getStringheComandi

    // Imposta le stringhe dei comandi
    public static void setStringheComandi (String StringheComandiTMP[]) {
    	for (int i = 0; i < 3; i++)
    		StringheComandi[i] = StringheComandiTMP[i];
    }       // Chiusura funzione setStringheComandi

    // Inizializza le stringhe dei comandi
    private static void LeggiStringheComandi (Context context) {
    	try {
    		// Ottengo oggetto lettura persistente
    		SharedPreferences StringheComandiSetting = context.getSharedPreferences ("HouseSpeech", Activity.MODE_PRIVATE);
    		// Leggo stringhe comandi salvate
    		StringheComandi = new String[3];
    		for (int i = 0; i < 3; i++)
    			StringheComandi[i] = StringheComandiSetting.getString (("StringaComando" + i), StringheComandiDefault[i]);
    	} catch (Exception e) {
    		for (int i = 0; i < 3; i++)
    			StringheComandi[i] = StringheComandiDefault[i];
    	}
    }       // Chiusura funzione LeggiStringheComandi

    // Memorizza nel RecordStore le stringhe dei comandi
    private static void MemorizzaStringheComandi (Context context) {
    	try {
    		// Ottengo oggetto scrittura persistente
    		SharedPreferences StringheComandiSetting = context.getSharedPreferences ("HouseSpeech", Activity.MODE_PRIVATE);
    		// Ottengo oggetto editor
    		SharedPreferences.Editor editor = StringheComandiSetting.edit();
    		// Aggiungo stringhe comandi
    		for (int i = 0; i < 3; i++)
    			editor.putString (("StringaComando" + i), StringheComandi[i]);
    		// Scrivo stringhe comandi
    		editor.commit();
    	} catch (Exception e) {}
    }       // Chiusura funzione MemorizzaStringheComandi
}		// Chiusura classe Utility